package com.htfp.service.usm.app.controller.manage;

import com.htfp.service.usm.app.model.BaseHttpResponse;
import com.htfp.service.usm.biz.model.request.BatchDeleteLabelRequest;
import com.htfp.service.usm.biz.model.request.InsertLabelRequest;
import com.htfp.service.usm.biz.model.request.UpdateLabelRequest;
import com.htfp.service.usm.biz.model.response.LabelVO;
import com.htfp.service.usm.biz.service.ILabelService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.validation.Valid;
import java.util.List;

/**
 * @author : shi_y
 * @description : 标签管理
 * @createTime : 2025-06-12 09:00
 **/

/**
 * 标签管理
 */
@Slf4j
@RestController
@RequestMapping("/manage/label")
public class LabelController {
    @Resource
    private ILabelService labelService;

    /**
     * 查询所有标签
     */
    @RequestMapping(value = "/queryAllLabels", method = RequestMethod.POST)
    public BaseHttpResponse<List<LabelVO>> queryAllLabels() {
        List<LabelVO> labelList= labelService.queryAllLabels();
        log.info("查询所有标签, 结果数量: {}", labelList.size());
        return BaseHttpResponse.success(labelList);
    }

    /**
     * 新增标签
     */
    @RequestMapping(value = "/insertLabel", method = RequestMethod.POST)
    public BaseHttpResponse<Integer> insertLabel(@RequestBody @Valid InsertLabelRequest insertLabelRequest) {
        log.info("新增标签: {}", insertLabelRequest);
        Integer id = labelService.insertLabel(insertLabelRequest);
        return BaseHttpResponse.success(id);
    }

    /**
     * 批量删除标签
     */
    @RequestMapping(value = "/batchDeleteLabel", method = RequestMethod.POST)
    public BaseHttpResponse<Void> batchDeleteLabel(@RequestBody @Valid BatchDeleteLabelRequest batchDeleteLabelRequest) {
        List<Integer> labelIdList = batchDeleteLabelRequest.getLabelIdList();
        log.info("批量删除标签: {}", labelIdList);
        labelService.batchDeleteLabels(labelIdList);
        return BaseHttpResponse.success();
    }

    /**
     * 修改标签
     */
    @RequestMapping(value = "/updateLabel", method = RequestMethod.POST)
    public BaseHttpResponse<Void> updateLabel(@RequestBody @Validated UpdateLabelRequest updateLabelRequest) {
        log.info("修改标签: {}", updateLabelRequest);
        labelService.updateLabel(updateLabelRequest);
        return BaseHttpResponse.success();
    }
}
