package com.htfp.service.usm.app.model;


import com.htfp.service.usm.common.enums.ErrorCodeEnum;
import lombok.Data;
import lombok.Getter;
import lombok.Setter;
import org.apache.ibatis.annotations.Select;

/**
 * @Author shi_y
 * @Date 2025-06-11
 * @Description http响应基类, Controller的统一响应结果
 */
@Data
public class BaseHttpResponse<T> {

    private boolean success;
    private Integer code;
    private String message;
    private T data;

    public BaseHttpResponse() {
    }

    public BaseHttpResponse(boolean success, Integer code, String message, T data) {
        this.success = success;
        this.code = code;
        this.message = message;
        this.data = data;
    }

    public BaseHttpResponse(boolean success, Integer code, String message) {
        this.success = success;
        this.code = code;
        this.message = message;
    }


    public BaseHttpResponse(boolean success, ErrorCodeEnum errorCodeEnum) {
        this.success = success;
        this.code = errorCodeEnum.getCode();
        this.message = errorCodeEnum.getDesc();
    }


    public BaseHttpResponse(boolean success, ErrorCodeEnum errorCodeEnum, T data) {
        this.success = success;
        this.code = errorCodeEnum.getCode();
        this.message = errorCodeEnum.getDesc();
        this.data = data;
    }

    public BaseHttpResponse(boolean success, T data) {
        this.success = success;
        this.data = data;
    }

    public BaseHttpResponse(boolean success) {
        this.success = success;
    }


    public static BaseHttpResponse<Void> success() {
        return new BaseHttpResponse<>(true, 0, "成功", null);
    }

    public static <T> BaseHttpResponse<T> success(T data) {
        return new BaseHttpResponse<>(true, 0, "成功", data);
    }

    public static BaseHttpResponse<Void> fail(ErrorCodeEnum errorCodeEnum) {
        return new BaseHttpResponse<>(false, errorCodeEnum);
    }


    public static BaseHttpResponse<Void> fail(ErrorCodeEnum errorCodeEnum, String msg) {
        return new BaseHttpResponse<>(false, errorCodeEnum.getCode(), msg);
    }

    public static <T> BaseHttpResponse<T> unknownError(T data) {
        return new BaseHttpResponse<>(false, ErrorCodeEnum.UNKNOWN_ERROR, data);
    }

}
