package com.htfp.service.usm.biz.model.request;


import com.htfp.service.usm.biz.validator.ValidEnum;
import com.htfp.service.usm.common.enums.UavMarkerEnum;
import com.htfp.service.usm.common.enums.UavUsageStatusEnum;
import lombok.Data;
import org.springframework.format.annotation.DateTimeFormat;


import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.util.List;

/**
 * @author : shi_y
 * @description :
 * @createTime : 2025-06-11 10:54
 **/
@Data
public class InsertUavInfoRequest {
    /**
     * uavId, 主键
     */
    private Integer id;

    /**
     * 无人机唯一识别码
     */
    @NotBlank(message = "无人机唯一识别码不能为空")
    private String uavSn;

    /**
     * 无人机编号, 例如1号机, 2号机...
     */
    @NotNull(message = "无人机编号不能为空")
    private Integer uavNumber;

    /**
     * 无人机型号: enum
     */
    @NotNull(message = "无人机型号不能为空")
    private Integer uavModel;

    /**
     * 无人机构型说明
     */
    private String configurationInfo;

    /**
     * 无人机生产厂家
     */
    @NotBlank(message = "无人机生产厂家不能为空")
    private String manufacturer;

    /**
     * 无人机生产日期
     */
    @NotNull(message = "无人机生产日期不能为空")
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    private LocalDate productionDate;

    /**
     * 无人机生产地点
     */
    @NotBlank(message = "无人机生产地点不能为空")
    private String productionSite;

    /**
     * 无人机出厂批次
     */
    @NotNull(message = "无人机出厂批次不能为空")
    private Integer productionBatch;

    /**
     * 无人机涂装标识: enum
     */
    @NotNull(message = "无人机涂装标识不能为空")
    @ValidEnum(enumClass = UavMarkerEnum.class, message = "无人机涂装类型枚举错误")
    private Integer paintMark;

    /**
     * 无人机使用状态: 0-闲置, 1-维修, 2-任务中, 3-试验, 4-交付, 5-报废, 6-库房中
     */
    @NotNull(message = "无人机使用状态不能为空")
    @ValidEnum(enumClass = UavUsageStatusEnum.class, message = "无人机使用类型枚举错误")
    private Integer usageStatus;

    /**
     * 无人机当前所在地
     */
    @NotBlank(message = "无人机当前所在地不能为空")
    private String currentLocation;

    /**
     * 无人机标签列表
     */
    private List<Integer> labelIdList;
}
