package com.htfp.service.usm.biz.service.impl;

import com.htfp.service.usm.biz.exception.BusinessException;
import com.htfp.service.usm.biz.model.request.InsertLabelRequest;
import com.htfp.service.usm.biz.model.request.UpdateLabelRequest;
import com.htfp.service.usm.biz.model.response.LabelVO;
import com.htfp.service.usm.biz.service.ILabelService;
import com.htfp.service.usm.biz.service.IUavLabelMappingService;
import com.htfp.service.usm.common.enums.ErrorCodeEnum;
import com.htfp.service.usm.dao.mapper.LabelMapper;
import com.htfp.service.usm.dao.model.entity.LabelDO;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.time.LocalDateTime;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @author : shi_y
 * @description :
 * @createTime : 2025-06-12 09:12
 **/
@Service
public class LabelServiceImpl implements ILabelService {
    @Resource
    private LabelMapper labelMapper;

    @Resource
    private IUavLabelMappingService uavLabelMappingService;

    /*InsertRequest -> 数据库DO
     * 更新createTime 和 updateTime
     */
    private LabelDO buildLabelDOFromInsertRequest(InsertLabelRequest insertLabelRequest) {
        return new LabelDO(null, insertLabelRequest.getLabelName(), insertLabelRequest.getLabelInfo(), 0, LocalDateTime.now(),  LocalDateTime.now());
    }

    /*UpdateRequest -> 数据库DO
     * 更新updateTime
     */
    private LabelDO buildLabelDOFromUpdateRequest(UpdateLabelRequest updateLabelRequest) {
        return new LabelDO(Long.valueOf(updateLabelRequest.getId()), updateLabelRequest.getLabelName(), updateLabelRequest.getLabelInfo(), 0, null,  LocalDateTime.now());
    }

    private LabelVO buildLabelVOFromDO(LabelDO labelDO) {
        return new LabelVO(labelDO.getId(), labelDO.getLabelName(), labelDO.getLabelInfo());
    }

    @Override
    public Integer insertLabel(InsertLabelRequest insertLabelRequest) {
        String labelName = insertLabelRequest.getLabelName();
        if (labelMapper.selectLabelByName(labelName)!=null) {
            throw new BusinessException(ErrorCodeEnum.DUPLICATE_ENTRY, "标签名称已存在");
        }
        LabelDO labelDO = buildLabelDOFromInsertRequest(insertLabelRequest);
        labelMapper.insertLabel(labelDO);
        return labelDO.getId().intValue();
    }

    @Override
    public List<LabelVO> queryAllLabels() {
        List<LabelDO> labelDOList = labelMapper.selectAll();
        return labelDOList.stream().map(this::buildLabelVOFromDO).collect(Collectors.toList());
    }

    @Override
    public List<Long> queryAllLabelsId() {
        return labelMapper.selectAllIds();
    }

    @Override
    public LabelVO queryLabelById(Integer id) {
        LabelDO labelDO = labelMapper.selectLabelById(id);
        return buildLabelVOFromDO(labelDO);
    }

    @Override
    public LabelVO queryLabelByName(String labelName) {
        LabelDO labelDO = labelMapper.selectLabelByName(labelName);
        return buildLabelVOFromDO(labelDO);
    }

    @Override
    public void batchDeleteLabels(List<Integer> labelIdList) {
        // 删除labelId对应的映射关系
        List<Long> labelIdListLong = labelIdList.stream().map(Long::valueOf).collect(Collectors.toList());
        uavLabelMappingService.removeAllLabelsByLabelIds(labelIdListLong);

        labelMapper.deleteLabels(labelIdList);
    }

    @Override
    public void updateLabel(UpdateLabelRequest updateLabelRequest) {
        LabelDO labelDO = buildLabelDOFromUpdateRequest(updateLabelRequest);
        labelMapper.updateLabel(labelDO);
    }
}
