package com.htfp.service.usm.biz.service.impl;

import com.htfp.service.usm.biz.exception.BusinessException;
import com.htfp.service.usm.biz.service.ILabelService;
import com.htfp.service.usm.biz.service.IUavInfoService;
import com.htfp.service.usm.biz.model.request.InsertUavInfoRequest;
import com.htfp.service.usm.biz.service.IUavLabelMappingService;
import com.htfp.service.usm.common.enums.ErrorCodeEnum;
import com.htfp.service.usm.dao.mapper.UavInfoMapper;
import com.htfp.service.usm.dao.model.entity.UavInfoDO;
import com.htfp.service.usm.dao.model.param.QueryUavInfoParam;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;

import javax.annotation.Resource;
import javax.validation.constraints.NotEmpty;
import java.time.LocalDateTime;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @author : shi_y
 * @description :
 * @createTime : 2025-06-10 17:33
 **/
@Service
public class UavInfoServiceImpl implements IUavInfoService {

    @Resource
    UavInfoMapper uavInfoMapper;
    @Resource
    ILabelService labelService;
    @Resource
    IUavLabelMappingService uavLabelMappingService;

    @Override
    public UavInfoDO queryUavInfoById(Integer uavId) {
        return uavInfoMapper.selectByUavId(Long.valueOf(uavId));
    }
    @Override
    public UavInfoDO queryUavInfoBySn(String uavSn) {
        return uavInfoMapper.selectByUavSn(uavSn);
    }
    @Override
    public List<UavInfoDO> queryUavInfoPageByCondition(QueryUavInfoParam queryUavInfoParam) {
        return uavInfoMapper.selectByCondition(queryUavInfoParam);
    }

    @Transactional
    @Override
    public Integer insertUavInfo(InsertUavInfoRequest insertUavInfoRequest) {
        // TODO 2025/6/11: 校验相关数据是否已存在
        if (queryUavInfoBySn(insertUavInfoRequest.getUavSn()) != null) {
            throw new BusinessException(ErrorCodeEnum.DUPLICATE_ENTRY, "无人机sn重复，请重新录入");
        }
        UavInfoDO uavInfoDO = buildUavInfoDOFromInsertRequest(insertUavInfoRequest);
        uavInfoDO.setCreateTime(LocalDateTime.now());
        uavInfoDO.setUpdateTime(LocalDateTime.now());
        uavInfoMapper.insertUavInfo(uavInfoDO);
        int uavId = uavInfoDO.getId().intValue();
        List<Integer> labelIdList = insertUavInfoRequest.getLabelIdList();
        if (!CollectionUtils.isEmpty(labelIdList)) {
            setUavLabelMapping(uavId, labelIdList);
        }
        return uavId;
    }

    /** 设置无人机标签*/
    @Override
    public void setUavLabelMapping(Integer uavId, @NotEmpty List<Integer> labelIdList) {
        // Set<Integer> existLabelIdList = uavLabelMappingMapper.selectLabelIdsByUavId(Long.valueOf(uavId));
        uavLabelMappingService.removeAllLabelsByUavId(Long.valueOf(uavId));
        List<Long> labelIdListLong = labelIdList.stream().map(Long::valueOf).collect(Collectors.toList());

        // 筛选不存在的标签
        List<Long> allLabelsInDB = labelService.queryAllLabelsId();
        List<Long> labelIdNotExist = labelIdListLong.stream()
                .filter(labelId -> !allLabelsInDB.contains((labelId))).collect(Collectors.toList());

        if (!CollectionUtils.isEmpty(labelIdNotExist)) {
            throw new BusinessException(ErrorCodeEnum.DATA_NOT_EXIST, "标签id="+labelIdNotExist.toString()+"不存在");
        }
        uavLabelMappingService.addLabels(Long.valueOf(uavId), labelIdListLong);
    }


    private UavInfoDO buildUavInfoDOFromInsertRequest(InsertUavInfoRequest insertUavInfoRequest) {
        return new UavInfoDO(null, insertUavInfoRequest.getUavSn(), insertUavInfoRequest.getUavNumber(), insertUavInfoRequest.getUavModel(), insertUavInfoRequest.getConfigurationInfo(), insertUavInfoRequest.getManufacturer(), insertUavInfoRequest.getProductionDate(), insertUavInfoRequest.getProductionSite(), insertUavInfoRequest.getProductionBatch(), insertUavInfoRequest.getPaintMark(), insertUavInfoRequest.getUsageStatus(), insertUavInfoRequest.getCurrentLocation(), 0, null, null);
    }



}
