package com.htfp.service.usm.biz.validator;

import javax.validation.Constraint;
import javax.validation.ConstraintValidator;
import javax.validation.ConstraintValidatorContext;
import javax.validation.Payload;
import java.lang.annotation.*;
import java.lang.reflect.Method;
import java.util.Arrays;
import java.util.List;

@Documented
@Constraint(validatedBy = EnumValueValidator.class)
@Target({ ElementType.FIELD, ElementType.PARAMETER })
@Retention(RetentionPolicy.RUNTIME)
public @interface ValidEnum {
    String message() default "Invalid enum value";
    Class<?>[] groups() default {};
    Class<? extends Payload>[] payload() default {};

    Class<? extends Enum<?>> enumClass();
}

class EnumValueValidator implements ConstraintValidator<ValidEnum, Object> {

    private List<Object> enumValues;

    @Override
    public void initialize(ValidEnum annotation) {
        try {
            Method method = annotation.enumClass().getMethod("values");
            enumValues = Arrays.asList((Enum[]) method.invoke(null));
        } catch (Exception e) {
            throw new IllegalArgumentException("Failed to initialize enum validator.");
        }
    }

    @Override
    public boolean isValid(Object value, ConstraintValidatorContext context) {
        if (value == null) return true;
        return enumValues.stream().anyMatch(v -> v.toString().equals(value.toString()));
    }
}