# 飞行记录单主表
create table uav_flight_record
(
    id                          int          not null auto_increment primary key comment 'uavId, 主键',
    task_uni_id                 varchar(64)  not null unique comment '飞行记录唯一识别码',
    task_name                   varchar(128) not null comment '任务名称',
    pilot_name                  varchar(128) not null comment '执飞人员列表', # 是否需要管理飞手
    uav_sn                      varchar(64)  not null unique comment '无人机唯一识别码',
    uav_id                      int          not null comment '无人机信息id, uav_basic_info.uavId',
    flight_date                 date         not null comment '飞行日期',

    start_time                  time         not null comment '开始时间',
    end_time                    time         not null comment '结束时间',

    flight_location             varchar(128) comment '飞行地点',
    flight_distance             int comment '飞行距离（km）',
    flight_mileage              int comment '飞行里程（km）',
    flight_duration             int comment '飞行时长（秒）',

    flight_altitude             int comment '平均飞行高度（米）',
    flight_speed_avg            int comment '平均飞行速度（m/s）',

    takeoff_airport_id          int comment '起飞机场id',
    landing_airport_id          int comment '降落机场id',

    takeoff_airport_temperature int comment '起飞机场温度（°c）',
    landing_airport_temperature int comment '降落机场温度（°c）',

    takeoff_wind_speed          int comment '起飞风速(m/s), 1位小数',
    takeoff_wind_direction      int comment '起飞风向(°), 整数',
    landing_wind_speed          int comment '降落风速(m/s), 1位小数',
    landing_wind_direction      int comment '降落风向(°), 整数',

    accumulation_flight_time    int comment '累计飞行时长（秒）',
    accumulation_flight_count   int comment '累计飞行次数',

    raw_data_form_id            varchar(64) comment '原始数据表单号',

    telemetry_data_path         varchar(256) comment '遥测 dat 文件路径',
    telemetry_command_path      varchar(256) comment '遥控指令 dat 文件路径',
    flight_param_path           varchar(256) comment '飞参 txt 文件路径',

    record_by                   varchar(32) comment '记录人',

    create_time                 datetime comment '创建时间',
    update_time                 datetime comment '更新时间',
#     create_by                   varchar(32) comment '创建人',
#     update_by                   varchar(32) comment '更新人',

    foreign key (uav_id) references uav_basic_info (id)                       # todo 记得删除
) comment '无人机飞行任务记录表';
