package com.htfp.service.usm.dao.mapper;

import com.htfp.service.usm.dao.constant.TableName;
import com.htfp.service.usm.dao.model.entity.LabelDO;
import org.apache.ibatis.annotations.*;

import java.util.List;

/**
* @author shi_y
* @description 针对表【label(标签表)】的数据库操作Mapper
* @createDate 2025-06-12 08:59:49
* @Entity com.htfp.service.usm.dao.model.entity.LabelDO
*/
@Mapper
public interface LabelMapper {
    String TABLE_NAME = TableName.LABEL;

    /**插入标签*/
    @Insert("insert into "+TABLE_NAME+ "(id, label_name, label_info, is_delete, create_time, update_time) values (#{id}, #{labelName}, #{labelInfo}, #{isDelete}, #{createTime}, #{updateTime})")
    @Options(useGeneratedKeys = true, keyColumn = "id", keyProperty = "id")
    void insertLabel(LabelDO labelDO);

    /**根据id查询标签*/
    @Select("select * from " + TABLE_NAME + " where id=#{id} and is_delete=0")
    LabelDO selectLabelById(@Param("id") Integer id);

    /**根据标签名称精确查询标签*/
    @Select("select * from " + TABLE_NAME + " where label_name=#{labelName} and is_delete=0")
    LabelDO selectLabelByName(@Param("labelName") String labelName);

    /**查询所有标签*/
    @Select("select * from "+TABLE_NAME+" where is_delete=0")
    List<LabelDO> selectAll();

    /**查询所有标签id*/
    @Select("select id from " + TABLE_NAME + " where is_delete=0")
    List<Long> selectAllIds();
    /**批量删除标签*/
    @Update("<script>" +
            "update "+TABLE_NAME+" set is_delete=1, update_time=NOW()" +
            " where id in" +
            " <foreach collection='ids' item='id' open='(' separator=',' close=')'>#{id}</foreach>" +
            "</script>")
    void deleteLabels(List<Integer> ids);

    /**更新标签*/
    @Update("update "+TABLE_NAME+" set label_name=#{labelName}, label_info=#{labelInfo}, update_time=#{updateTime} where id=#{id} and is_delete=0")
    void updateLabel(LabelDO labelDO);


}




