package com.htfp.service.usm.dao.mapper;

import com.htfp.service.usm.dao.constant.TableName;
import com.htfp.service.usm.dao.model.mapping.UavLabelMappingDO;
import org.apache.ibatis.annotations.Insert;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Update;

import java.util.List;
import java.util.Set;

/**
 * @author shi_y
 * @description 针对表【uav_label_mapping(无人机与标签的映射表)】的数据库操作Mapper
 * @createDate 2025-06-12 11:00:52
 * @Entity com.htfp.service.usm.dao.model.mapping.UavLabelMappingDO
 */
@Mapper
public interface UavLabelMappingMapper {
    String TABLE_NAME = TableName.UAV_LABEL_MAPPING;

    @Insert("<script>" +
            "insert into " + TABLE_NAME + "(uav_id, label_id, create_time, update_time) values " +
            "<foreach collection='uavLabelMappingDOList' item='item' separator=','>" +
            "(#{item.uavId}, #{item.labelId}, #{item.createTime}, #{item.updateTime})" +
            "</foreach>" +
            "</script>")
    int batchInsert(List<UavLabelMappingDO> uavLabelMappingDOList);

    @Insert("select id from uav_label_mapping where uav_id=#{uavId} and is_delete=0")
    Set<Integer> selectLabelIdsByUavId(@Param("uavId") Long uavId);


    /**删除uavId对应的所有标签*/
    @Update("update " + TABLE_NAME + " set is_delete = 1, update_time = NOW() where uav_id = #{uavId} and is_delete = 0")
    int deleteByUavId(Long uavId);

    /**删除指定标签*/
    @Update("<script>" +
            "update " + TABLE_NAME + " set is_delete = 1, update_time = NOW() " +
            "where is_delete=0 and label_id in " +
            "<foreach collection='labelIdList' item='id' open='(' separator=',' close=')'>#{id}</foreach>" +
            "</script>"
    )
    int deleteByLabelIds(List<Long> labelIdList);

    /**删除uavId的指定标签*/
    @Update("<script>" +
            "update " + TABLE_NAME + " set is_delete = 1, update_time=NOW() " +
            "where uav_id = #{uavId} and is_delete=0 and label_id in " +
            "<foreach collection='labelIdList' item='id' open='(' separator=',' close=')'>#{id}</foreach>" +
            "</script>")
    int deleteLabelMapping(Long uavId, List<Long> labelIdList);

}




